# frozen_string_literal: true

module ErpIntegration
  # The `ErpIntegration::Error` is the default error class for any exception raised
  # on purpose by this gem.
  class Error < StandardError; end

  # The `ErpIntegration::BadConfiguration` is raised whenever the newly provided
  # configuration is not a valid configuration object.
  class BadConfiguration < Error
    def initialize
      super(
        '[ERP Integration] The provided configuration object is not a ' \
          'ErpIntegration::Configuration instance. Please provide a '  \
          'ErpIntegration::Configuration instance when overriding the configuration directly.'
      )
    end
  end

  class ResourceNotFound < Error
    def initialize
      super "[ERP Integration] Couldn't find the requested resource."
    end
  end

  class HttpError < Faraday::Error
    class BadRequest < HttpError; end
    class AuthorizationRequired < HttpError; end
    class PaymentRequired < HttpError; end
    class Forbidden < HttpError; end
    class NotFound < HttpError; end
    class MethodNotAllowed < HttpError; end
    class NotAccepted < HttpError; end
    class UnprocessableEntity < HttpError; end
    class TooManyRequests < HttpError; end
    class InternalServerError < HttpError; end
  end
end
