# frozen_string_literal: true

module ErpIntegration
  module Middleware
    # The `ErrorHandling` middleware allows to raise our own exceptions that
    # are easier to catch for the host application (e.g. `mejuri-web`).
    class ErrorHandling < Faraday::Response::Middleware
      HTTP_ERROR_CODES = {
        400 => ErpIntegration::HttpError::BadRequest,
        401 => ErpIntegration::HttpError::AuthorizationRequired,
        402 => ErpIntegration::HttpError::PaymentRequired,
        403 => ErpIntegration::HttpError::Forbidden,
        404 => ErpIntegration::HttpError::NotFound,
        405 => ErpIntegration::HttpError::MethodNotAllowed,
        406 => ErpIntegration::HttpError::NotAccepted,
        422 => ErpIntegration::HttpError::UnprocessableEntity,
        429 => ErpIntegration::HttpError::TooManyRequests,
        500 => ErpIntegration::HttpError::InternalServerError
      }.freeze

      def on_complete(response)
        key = response[:status].to_i
        raise HTTP_ERROR_CODES[key], response_values(response) if HTTP_ERROR_CODES.key?(key)
      end

      def response_values(response)
        { status: response.status, headers: response.response_headers, body: response.body }
      end
    end
  end
end
