# frozen_string_literal: true

module ErpIntegration
  module Resources
    module Validations
      # Exposes all errors related to an `ErpIntegration::Resource`.
      #
      # @return [ErpIntegration::Resources::Errors] Encapsulation of all error messages.
      def errors
        @errors ||= Resources::Errors.new
      end

      # Checks whether an resource is considered valid or not.
      #
      # @return [Boolean] Is the resource valid according to the ERP?
      def valid?
        errors.none?
      end

      # Validates the resource by checking the given error messages.
      #
      # @param error_messages [Array] A list of error messages.
      # @return [Boolean] Whether the resource is valid or not.
      def validate_with(*error_messages)
        errors.clear

        error_messages.flatten.compact.each do |error_message|
          errors.add(error_message)
        end

        valid?
      end
    end
  end
end
